/// Library using [erikflowers/WeatherIcons](https://erikflowers.github.io/weather-icons/) in a Flutter app.
///
/// [WeatherIcons] class contains all of the icons.  Along with a helper function
/// converting from CSS class names to the [IconData].
///
/// Example:
///
///     IconButton(
///       icon: Icon(WeatherIcons.rain),
///       onPressed: () { print("Hello World"); }
///     );
///
/// [WindIcon] is a helper widget for creating a rotated wind symbol.
///
/// Example Wind usage:
///
///     // Using a preset angle
///     IconButton(
///       icon: WindIcon.towards_ne,
///       onPressed: () { print("Hello World"); }
///     );
///
///     // Using a custom angle between 0-360
///     IconButton(
///       icon: WindIcon(angle: 45),
///       onPressed: () { print("Hello World"); }
///     );
///
/// **Note** the [WeatherIcons] data is auto-generated by scraping the font webpage, and
/// the font file is downloaded automatically.
library weather_icons;

export 'package:weather_icons/src/time_icon.dart';
export 'package:weather_icons/src/weather_icons_g.dart';
export 'package:weather_icons/src/wind_icon.dart';
